==> rivendell-2.15.3.tar.gz: rivendell-2.15.3/utils/rdgpimon/rdgpimon_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>Database Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <comment>Unable to connect to mySQL Server!</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to connect to mySQL Server!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matrix:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPI (Inputs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPO (Outputs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green = ON Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red = OFF Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Both</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Events Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ON </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-3.4.1.tar.gz: rivendell-3.4.1/utils/rdgpimon/rdgpimon_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>MainWidget</name>
    <message>
        <source>Matrix:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPI (Inputs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPO (Outputs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green = ON Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red = OFF Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Both</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Events Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ON </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
